@@ -2,26 +2,42 @@ import pytest
 
 import numpy as np
 from sklearn.preprocessing import normalize
-from spacy.vocab import Vocab
-from spacy.language import Language
 
 from whatlies.language import SpacyLanguage
-from whatlies.transformers import (
-    Umap,
-    Pca,
-    Noise,
-    AddRandom,
-    Tsne,
-    OpenTsne,
-    # Ivis,
-    Normalizer,
-)
+from whatlies.transformers import Noise, AddRandom, Normalizer, Umap, Tsne, Pca
 from whatlies.transformers._transformer import Transformer, SklearnTransformer
 
+words = [
+    "prince",
+    "princess",
+    "nurse",
+    "doctor",
+    "banker",
+    "man",
+    "woman",
+    "cousin",
+    "neice",
+    "king",
+    "queen",
+    "dude",
+    "guy",
+    "gal",
+    "fire",
+    "dog",
+    "cat",
+    "mouse",
+    "red",
+    "bluee",
+    "green",
+    "yellow",
+    "water",
+    "person",
+    "family",
+    "brother",
+    "sister",
+]
 
-vocab = Vocab().from_disk("tests/custom_test_vocab/")
-words = list(vocab.strings)
-lang = SpacyLanguage(nlp=Language(vocab=vocab, meta={"lang": "en"}))
+lang = SpacyLanguage("en_core_web_sm")
 emb = lang[words]
 
 transformers = [
@@ -36,13 +52,10 @@ transformers = [
     lambda d: d | (d["man"] - d["woman"]),
     Tsne(2, n_iter=250),
     Tsne(3, n_iter=250),
-    OpenTsne(2, n_iter=2),
-    # Ivis(2, k=10, batch_size=10, epochs=10),
-    # Ivis(3, k=10, batch_size=10, epochs=10),
     Normalizer(),
     Normalizer(feature=True),
 ]
-extra_sizes = [0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0, 0]
+extra_sizes = [0, 0, 0, 0, 0, 0, 4, 1, 0, 0, 0, 0, 0, 0, 0]
 tfm_ids = [_.__class__.__name__ for _ in transformers]
 
 
@@ -61,8 +74,6 @@ def test_transformations_new_size(transformer, extra_size):
         Pca(2),
         Noise(0.1),
         Tsne(2, n_iter=250),
-        OpenTsne(2, n_iter=1),
-        # Ivis(2, k=10, batch_size=10, epochs=10),
         AddRandom(n=4),
         lambda d: d | (d["man"] - d["woman"]),
         Normalizer(),
@@ -82,8 +93,6 @@ def test_transformations_keep_props(transformer):
         Noise(0.1),
         AddRandom(n=4),
         Tsne(2, n_iter=250),
-        OpenTsne(2, n_iter=2),
-        # Ivis(2, k=10, batch_size=10, epochs=10),
         Normalizer(),
     ],
 )
@@ -97,8 +106,6 @@ def test_transformers_are_subclassed_properly(transformer):
         Umap(2),
         Pca(2),
         Tsne(2, n_iter=250),
-        OpenTsne(2, n_iter=2),
-        # Ivis(2, k=10, batch_size=10, epochs=10),
     ],
 )
 def test_sklearn_transformers_are_subclassed_properly(transformer):
